@@ -63,10 +63,43 @@ def change_sec_to_ffmpeg_time_format(time_input):
     return hour_min_second_format_string + millisecond_string
 
 
+# This function is to update gaze.csv by add 1 column called local_time
+def update_gaze_csv(csv_dir_input, ts_column_name):
+    csv_data_array = []
+    with open(csv_dir_input, "r") as csv_file:
+        csv_data = csv.reader(csv_file, delimiter=',')
+        header_array = next(csv_data)
+        data_position = get_position(ts_column_name, header_array)
+        start_time = None
+        start_time_noted = False
+        for data in csv_data:
+            if not start_time_noted:
+                start_time = float(data[data_position])
+                start_time_noted = True
+            local_time = str(float(data[data_position]) - start_time)
+            data.append(local_time)
+            csv_data_array.append(data)
+        csv_file.close()
+
+    header_array.append("local_time")
+    out_put_csv = csv_dir_input.replace(".csv", "_updated.csv")
+    with open(out_put_csv, mode='w', newline="") as destination_file:
+        csv_writer = csv.DictWriter(destination_file, fieldnames=header_array)
+        csv_writer.writeheader()
+        for row in csv_data_array:
+            temp_dict = {}
+            for index, header in enumerate(header_array):
+                temp_dict[header] = row[index]
+            csv_writer.writerow(temp_dict)
+        destination_file.close()
+    print("")
+    print(f"{csv_dir_input} is updated")
+
+
 def main():
     parser = argparse.ArgumentParser(prog='pim_video',
                                      description='PIM_VIDEO package.')
-    parser.add_argument('--version', action='version', version='1.0.3'),
+    parser.add_argument('--version', action='version', version='1.0.6'),
     parser.add_argument("-d", dest="input_directory", required=True, default=sys.stdin,
                         help="directory folder to be processed", metavar="directory name")
 
@@ -112,12 +145,14 @@ def main():
                 print("Essential software, ffmpeg is found and start processing...")
                 print("")
                 os.chdir(input_dir)
+                # update the gaze.csv
+                update_gaze_csv("gaze.csv", "sensor_timestamp")
 
                 # rotate the videos
                 left_v_rotate_cmd = "ffmpeg -i left_video.mp4 -vf \"transpose=2\" -b:v 10M -c:a copy " \
-                                    "left_video_rotated.mp4 "
+                                    "left_video_rotated.mp4 -y"
                 right_v_rotate_cmd = "ffmpeg -i right_video.mp4 -vf \"transpose=2\" -b:v 10M -c:a copy " \
-                                     "right_video_rotated.mp4 "
+                                     "right_video_rotated.mp4 -y"
                 os.system(left_v_rotate_cmd)
                 os.system(right_v_rotate_cmd)
                 print("")
@@ -125,13 +160,13 @@ def main():
                 print("")
 
                 # read left and right timestamps
-                left_csv_dir = os.path.join(input_dir, "left_eye_timestamp.csv")
-                left_timestamp = get_timestamp_from_csv(left_csv_dir, "left_eye_timestamp")
+                # left_csv_dir = os.path.join(input_dir, "left_eye_timestamp.csv")
+                left_timestamp = get_timestamp_from_csv("left_eye_timestamp.csv", "left_eye_timestamp")
                 print("")
                 print(f"Left timestamp: {left_timestamp}")
                 print("")
-                right_csv_dir = os.path.join(input_dir, "right_eye_timestamp.csv")
-                right_timestamp = get_timestamp_from_csv(right_csv_dir, "right_eye_timestamp")
+                # right_csv_dir = os.path.join(input_dir, "right_eye_timestamp.csv")
+                right_timestamp = get_timestamp_from_csv("right_eye_timestamp.csv", "right_eye_timestamp")
                 print("")
                 print(f"Right timestamp: {right_timestamp}")
                 print("")
@@ -168,7 +203,7 @@ def main():
                     right_v_trim_cmd = f"ffmpeg -i right_video_rotated.mp4 " \
                                        f"-ss {timestamp_diff_ffmpeg_format} " \
                                        f"-t {right_available_length_ffmpeg_format} " \
-                                       f"-b:v 10M -c:a copy right_video_trimmed.mp4"
+                                       f"-b:v 10M -c:a copy right_video_trimmed.mp4 -y"
                     os.system(right_v_trim_cmd)
                     print("")
                     print("Right video is trimmed.")
@@ -180,7 +215,7 @@ def main():
                     left_v_trim_cmd = f"ffmpeg -i left_video_rotated.mp4 " \
                                       f"-ss {timestamp_diff_ffmpeg_format} " \
                                       f"-t {left_available_length_ffmpeg_format} " \
-                                      f"-b:v 10M -c:a copy left_video_trimmed.mp4"
+                                      f"-b:v 10M -c:a copy left_video_trimmed.mp4 -y"
                     os.system(left_v_trim_cmd)
                     print("")
                     print("Left video is trimmed.")
@@ -188,9 +223,9 @@ def main():
 
                 # merge videos
                 right_trim_merge_cmd = "ffmpeg -i left_video_rotated.mp4 -i right_video_trimmed.mp4 -filter_complex " \
-                                       "hstack=inputs=2:shortest=1 -b:v 10M -c:a copy left_right_combined.mp4 "
+                                       "hstack=inputs=2:shortest=1 -b:v 10M -c:a copy left_right_combined.mp4 -y"
                 left_trim_merge_cmd = "ffmpeg -i left_video_trimmed.mp4 -i right_video_rotated.mp4 -filter_complex " \
-                                      "hstack=inputs=2:shortest=1 -b:v 10M -c:a copy left_right_combined.mp4 "
+                                      "hstack=inputs=2:shortest=1 -b:v 10M -c:a copy left_right_combined.mp4 -y"
                 if trim_type == "right":
                     os.system(right_trim_merge_cmd)
                     print("")
